@@ -2,7 +2,7 @@
 a basis for most other modules"""
 __author__ = 'George Oblapenko'
 __license__ = "GPL"
-__version__ = "0.3.1"
+__version__ = "0.3.5"
 __maintainer__ = "George Oblapenko"
 __email__ = "kunstmord@kunstmord.com"
 __status__ = "Production"
@@ -33,7 +33,7 @@ class Molecule_sts:
     avc - anharmonicity coefficient, for vibrational energies
     diss - dissociation energy
     LJe - the Lennard-Jones epsilon parameter
-    LJs - the Lennard-Jones epsilon parameter
+    LJs - the Lennard-Jones sigma parameter
     rot - array of rotational energies
     vibr - array of vibrational energies
     vibr_zero - vibrational energy of the 0-th vibrational level (since the Treanor distribution requires the energy
@@ -59,20 +59,21 @@ class Molecule_sts:
         raw_d = np.genfromtxt(join(this_dir, normcase('data/particles/' + self.name + '.dat')))
         self.mass = raw_d[0] * constants.physical_constants['atomic mass constant'][0]
         self.num_rot = int(raw_d[1])
+        self.rot_symmetry = raw_d[2]
         if vmodel == 'harmonic':
-            self.num_vibr = int(raw_d[2])
-            self.max_vibr = self.num_vibr
-        elif vmodel == 'anharmonic' or vmodel == 'table':
             self.num_vibr = int(raw_d[3])
             self.max_vibr = self.num_vibr
-        self.inertia = raw_d[4] * (10 ** (-46))
+        elif vmodel == 'anharmonic' or vmodel == 'table':
+            self.num_vibr = int(raw_d[4])
+            self.max_vibr = self.num_vibr
+        self.inertia = raw_d[5] * (10 ** (-46))
         self.rot_const = (constants.h ** 2) / (8.0 * (constants.pi ** 2) * self.inertia)
-        self.hvc = raw_d[5] * 100 * constants.h * constants.c
-        self.avc = raw_d[6]
-        self.diss = raw_d[7] * constants.physical_constants['electron volt'][0]
-        self.form = raw_d[8] * constants.physical_constants['electron volt'][0]
-        self.LJe = raw_d[9]  # stored as eps/kboltz
-        self.LJs = raw_d[10] * constants.physical_constants['Angstrom star'][0]
+        self.hvc = raw_d[6] * 100 * constants.h * constants.c
+        self.avc = raw_d[7]
+        self.diss = raw_d[8] * constants.physical_constants['electron volt'][0]
+        self.form = raw_d[9] * constants.physical_constants['electron volt'][0]
+        self.LJe = raw_d[10]  # stored as eps/kboltz
+        self.LJs = raw_d[11] * constants.physical_constants['Angstrom star'][0]
         self.rot = np.zeros(self.num_rot + 1)
         self.vibr = np.zeros(self.num_vibr + 1)
         self.vibr_zero = 0
@@ -256,7 +257,7 @@ class Molecule_sts:
         j - rotational level (may be an np.array of indices, result will then be an array)
         T - the temperature of the mixture
         """
-        return (2.0 * j + 1.0) * np.exp(-self.rot[j] / (constants.k * T))
+        return ((2.0 * j + 1.0) / self.rot_symmetry) * np.exp(-self.rot[j] / (self.rot_symmetry * constants.k * T))
 
     def Z_rot(self, T):
         """Returns the rotational partition function Z_rot(T)
@@ -268,7 +269,7 @@ class Molecule_sts:
         T - the temperature of the mixture
         """
         if self.current_T != T:
-            return 4.0 * constants.pi**2 * self.inertia * constants.k * T / (constants.h**2)
+            return 8.0 * (constants.pi ** 2) * self.inertia * constants.k * T / (self.rot_symmetry * (constants.h ** 2))
         else:
             return self.current_Z_rot
 
