@@ -4,7 +4,7 @@ TODO - LJ and IPL for various other Omega^(l, r) integrals, VSS too perhaps?
 """
 __author__ = 'George Oblapenko'
 __license__ = "GPL"
-__version__ = "0.3.1"
+__version__ = "0.3.5"
 __maintainer__ = "George Oblapenko"
 __email__ = "kunstmord@kunstmord.com"
 __status__ = "Development"
@@ -12,64 +12,11 @@ __status__ = "Development"
 
 import numpy as np
 from scipy import constants
-from csv import reader
 from scipy.special import gamma
-from os.path import normcase, join, split
 from scipy.misc import factorial
 from errors import OmegaError
 
 
-def load_interaction(partner1, partner2):
-    """Loads interaction parameters for two partners for use in various integrals (loads Lenard-Jones, IPL and VSS
-    potential parameters + calculates collision radius and collision-reduced mass) from the file interactions.csv
-    The values are stored as the following units:
-    phizero - electron-volt, beta - 1 / Angstrom
-
-    Returns:
-    An array, which contains the following quantities:
-    result[0] - collision-reduced mass
-    result[1] - collision radius
-    result[2] - Lennard-Jones epsilon parameter
-    result[3] - phizero parameter for the IPL potential, divided by Boltzmann constants (i.e. expressed as a
-                                                                                         temperature)
-    result[4] - beta parameter for the IPL potential
-    result[5] - C parameter for the VSS model for the Omega^(1,1) integral
-    result[6] - omega parameter for the VSS model for the Omega^(1,1) integral
-    result[7] - C parameter for the VSS model for the Omega^(2,2) integral
-    result[8] - omega parameter for the VSS model for the Omega^(2,2) integral
-    result[9] - C parameter for the VSS model for the Omega_total integral
-    result[10] - omega parameter for the VSS model for the Omega_total integral
-    result[11] - C parameter for the VSS model for the deflection angle
-    result[12] - omega parameter for the VSS model for the deflection angle
-
-    Takes as input:
-    partner1 - the first colliding partner
-    partner2 - the second colliding partner
-
-    Notes:
-    Deflection angle parameters are needed to calculate amount of collisions needed to establish rotational
-    equilibrium using the VSS model
-    """
-    m = (partner1.mass * partner2.mass)/(partner1.mass + partner2.mass)
-    sigma = (partner1.LJs + partner2.LJs) * 0.5
-    eps = np.sqrt(partner1.LJe * partner2.LJe * ((partner1.LJs * partner2.LJs) ** 6)) / (sigma ** 6)
-    this_dir, this_filename = split(__file__)
-    csv_file_object = reader(open(join(this_dir, normcase('data/models/interactions.csv')), 'r'))
-    csv_file_object.next()
-    res = np.zeros(13)
-    res[:3] = [m, sigma, eps]
-
-    for row in csv_file_object:
-        if (row[0] == partner1.name and row[1] == partner2.name) or\
-                (row[1] == partner1.name and row[0] == partner2.name):
-            rd = np.array(row[2:]).astype(np.float)
-            res[3:] = [rd[0], rd[1], rd[2], rd[3], rd[4], rd[5], rd[6], rd[7], rd[8], rd[9]]
-
-    res[3] *= constants.physical_constants['electron volt'][0] / constants.k
-    res[4] *= 1.0 / constants.physical_constants['Angstrom star'][0]
-    return res
-
-
 def rigid_sphere_omega(T, l, r, m, sigma, nokt=False):
     """Returns the Omega^(l,r)-integral for a rigid sphere potential for any l > 0  and r > 0
 
